@@ -1,9 +1,6 @@
 import imp
 from typing import Optional, Union
-import cv2
-import numpy as np
-import easyocr
-import matplotlib.pyplot as pl
+
 from pyallied.web.print_page_options import PrintOptions
 from pyallied.web.webWaits import customwebDriverwait
 from pyallied.web.log_type import log_type
@@ -165,17 +162,7 @@ class Browser(customwebDriverwait):
         except Exception as error:
             raise error    
 
-    '''
-    returns the embedded text in the image.
-    It returns a list of detected text, with each text element containing three types of information. 
-    Which are: the text, its bounding box vertices, and the confidence level of the text detection
-    '''    
-    def get_embeddedText_from_image(self,path:str):
-        try:
-            reader= easyocr.Reader(['en'])
-            return reader.readtext(path)
-        except Exception as error:
-            raise error        
+       
     '''
     Goes one step forward in the browser history.
 
